import imageInputFileToBase64 from "./media/imageInputFileToBase64";
import imageInputToBase64 from "./media/imageInputToBase64";
import inputFileToBase64 from "./media/inputFileToBase64";
import getAccessToken from "./auth/google/getAccessToken";
import getGithubAccessToken from "./auth/github/getAccessToken";
import logout from "./auth/logout";
import fetchApi from "./fetch";
import serializeQuery from "../package-shared/utils/serialize-query";
import serializeCookies from "../package-shared/utils/serialize-cookies";
import numberfy from "../package-shared/utils/numberfy";
import slugify from "../package-shared/utils/slugify";
import postLogin from "./auth/post-login";
import deserializeQuery from "../package-shared/utils/deserialize-query";
import debugLog from "../package-shared/utils/logging/debug-log";
/**
 * Main Export
 */
declare const datasquirelClient: {
    media: {
        imageInputToBase64: typeof imageInputToBase64;
        imageInputFileToBase64: typeof imageInputFileToBase64;
        inputFileToBase64: typeof inputFileToBase64;
    };
    auth: {
        google: {
            getAccessToken: typeof getAccessToken;
        };
        github: {
            getAccessToken: typeof getGithubAccessToken;
        };
        logout: typeof logout;
        postLogin: typeof postLogin;
    };
    fetch: {
        fetchApi: typeof fetchApi;
        clientFetch: typeof fetchApi;
    };
    utils: {
        deserializeQuery: typeof deserializeQuery;
        serializeQuery: typeof serializeQuery;
        serializeCookies: typeof serializeCookies;
        EJSON: {
            parse: (string: string | null | number, reviver?: (this: any, key: string, value: any) => any) => {
                [s: string]: any;
            } | {
                [s: string]: any;
            }[] | undefined;
            stringify: (value: any, replacer?: ((this: any, key: string, value: any) => any) | null, space?: string | number) => string | undefined;
        };
        numberfy: typeof numberfy;
        slugify: typeof slugify;
        debugLog: typeof debugLog;
    };
};
export default datasquirelClient;
