"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = deleteFile;
const grab_host_names_1 = __importDefault(require("../utils/grab-host-names"));
/**
 * # Delete File via API
 */
function deleteFile(_a) {
    return __awaiter(this, arguments, void 0, function* ({ key, url, user_id, }) {
        const grabedHostNames = (0, grab_host_names_1.default)();
        const { host, port, scheme } = grabedHostNames;
        try {
            /**
             * Make https request
             *
             * @description make a request to datasquirel.com
             */
            const httpResponse = yield new Promise((resolve, reject) => {
                const reqPayload = JSON.stringify({ url: url });
                const httpsRequest = scheme.request({
                    method: "POST",
                    headers: {
                        "Content-Type": "application/json",
                        "Content-Length": Buffer.from(reqPayload).length,
                        Authorization: key ||
                            process.env.DSQL_FULL_ACCESS_API_KEY ||
                            process.env.DSQL_API_KEY,
                    },
                    port,
                    hostname: host,
                    path: `/api/query/${user_id || grabedHostNames.user_id}/delete-file`,
                }, 
                /**
                 * Callback Function
                 *
                 * @description https request callback
                 */
                (response) => {
                    var str = "";
                    response.on("data", function (chunk) {
                        str += chunk;
                    });
                    response.on("end", function () {
                        resolve(JSON.parse(str));
                    });
                    response.on("error", (err) => {
                        reject(err);
                    });
                });
                httpsRequest.write(reqPayload);
                httpsRequest.end();
            });
            return httpResponse;
        }
        catch ( /** @type {*} */error) {
            console.log("Error deleting file: ", error.message);
            return {
                success: false,
                payload: null,
                msg: error.message,
            };
        }
    });
}
