"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = updateUsersTableSchema;
const serverError_1 = __importDefault(require("./serverError"));
const grabUserSchemaData_1 = __importDefault(require("./grabUserSchemaData"));
const setUserSchemaData_1 = __importDefault(require("./setUserSchemaData"));
const createDbFromSchema_1 = __importDefault(require("../../shell/createDbFromSchema"));
const grabSchemaFieldsFromData_1 = __importDefault(require("./grabSchemaFieldsFromData"));
/**
 * # Add User Table to Database
 */
function updateUsersTableSchema(_a) {
    return __awaiter(this, arguments, void 0, function* ({ userId, database, newFields, newPayload, }) {
        var _b, _c, _d;
        try {
            const dbFullName = database;
            const userSchemaData = (0, grabUserSchemaData_1.default)({ userId });
            if (!userSchemaData)
                throw new Error("User schema data not found!");
            let targetDatabaseIndex = userSchemaData.findIndex((db) => db.dbFullName === database);
            if (targetDatabaseIndex < 0) {
                throw new Error("Couldn't Find Target Database!");
            }
            let existingTableIndex = (_b = userSchemaData[targetDatabaseIndex]) === null || _b === void 0 ? void 0 : _b.tables.findIndex((table) => table.tableName === "users");
            const usersTable = userSchemaData[targetDatabaseIndex].tables[existingTableIndex];
            if (!((_c = usersTable === null || usersTable === void 0 ? void 0 : usersTable.fields) === null || _c === void 0 ? void 0 : _c[0]))
                throw new Error("Users Table Not Found!");
            const additionalFields = (0, grabSchemaFieldsFromData_1.default)({
                fields: newFields,
                data: newPayload,
            });
            const spliceStartIndex = usersTable.fields.findIndex((field) => field.fieldName === "date_created");
            const finalSpliceStartIndex = spliceStartIndex >= 0 ? spliceStartIndex : 0;
            usersTable.fields.splice(finalSpliceStartIndex, 0, ...additionalFields);
            (0, setUserSchemaData_1.default)({ schemaData: userSchemaData, userId });
            const dbShellUpdate = yield (0, createDbFromSchema_1.default)({
                userId,
                targetDatabase: dbFullName,
            });
            return `Done!`;
        }
        catch (error) {
            (_d = global.ERROR_CALLBACK) === null || _d === void 0 ? void 0 : _d.call(global, `Error Updating User Table Schema`, error);
            (0, serverError_1.default)({
                component: "addUsersTableToDb",
                message: error.message,
                user: { id: userId },
            });
            return error.message;
        }
    });
}
