"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = varDatabaseDbHandler;
const parseDbResults_1 = __importDefault(require("./parseDbResults"));
const serverError_1 = __importDefault(require("./serverError"));
const grab_dsql_connection_1 = __importDefault(require("../../utils/grab-dsql-connection"));
const conn_db_handler_1 = __importDefault(require("../../utils/db/conn-db-handler"));
/**
 * # DB handler for specific database
 */
function varDatabaseDbHandler(_a) {
    return __awaiter(this, arguments, void 0, function* ({ queryString, queryValuesArray, database, tableSchema, debug, }) {
        var _b;
        let CONNECTION = (0, grab_dsql_connection_1.default)({ fa: true });
        if (global.DSQL_USE_LOCAL)
            CONNECTION = (0, grab_dsql_connection_1.default)({ local: true });
        if (database === null || database === void 0 ? void 0 : database.match(/^datasquirel$/))
            CONNECTION = (0, grab_dsql_connection_1.default)();
        if (debug) {
            console.log(`varDatabaseDbHandler:query:`, queryString);
            console.log(`varDatabaseDbHandler:values:`, queryValuesArray);
            console.log(`varDatabaseDbHandler:CONNECTION:`, CONNECTION.getConfig());
        }
        let results = yield (0, conn_db_handler_1.default)(CONNECTION, queryString, queryValuesArray);
        if (debug) {
            console.log(`varDatabaseDbHandler:results:`, results);
        }
        if (results && tableSchema) {
            try {
                const unparsedResults = results;
                const parsedResults = yield (0, parseDbResults_1.default)({
                    unparsedResults: unparsedResults,
                    tableSchema: tableSchema,
                });
                return parsedResults;
            }
            catch (error) {
                console.log("\x1b[31mvarDatabaseDbHandler ERROR\x1b[0m =>", database, error);
                (_b = global.ERROR_CALLBACK) === null || _b === void 0 ? void 0 : _b.call(global, `VarDb Handler Error`, error);
                (0, serverError_1.default)({
                    component: "varDatabaseDbHandler/lines-52-53",
                    message: error.message,
                });
                return null;
            }
        }
        else if (results) {
            return results;
        }
        else {
            return null;
        }
    });
}
