"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = generateTypeDefinition;
const default_fields_regexp_1 = __importDefault(require("./default-fields-regexp"));
function generateTypeDefinition({ paradigm, table, query, typeDefName, allValuesOptional, addExport, }) {
    let typeDefinition = ``;
    try {
        const tdName = typeDefName ||
            `DSQL_${query.single}_${query.single_table}`.toUpperCase();
        const fields = table.fields;
        function typeMap(type) {
            if (type === null || type === void 0 ? void 0 : type.match(/int/i)) {
                return "number";
            }
            if (type === null || type === void 0 ? void 0 : type.match(/text|varchar|timestamp/i)) {
                return "string";
            }
            return "string";
        }
        const typesArrayTypeScript = [];
        const typesArrayJavascript = [];
        typesArrayTypeScript.push(`${addExport ? "export " : ""}type ${tdName} = {`);
        typesArrayJavascript.push(`/**\n * @typedef {object} ${tdName}`);
        fields.forEach((field) => {
            var _a;
            const nullValue = allValuesOptional
                ? "?"
                : field.nullValue
                    ? "?"
                    : ((_a = field.fieldName) === null || _a === void 0 ? void 0 : _a.match(default_fields_regexp_1.default))
                        ? "?"
                        : "";
            typesArrayTypeScript.push(`    ${field.fieldName}${nullValue}: ${typeMap(field.dataType || "")};`);
            typesArrayJavascript.push(` * @property {${typeMap(field.dataType || "")}${nullValue}} ${field.fieldName}`);
        });
        typesArrayTypeScript.push(`}`);
        typesArrayJavascript.push(` */`);
        if (paradigm === null || paradigm === void 0 ? void 0 : paradigm.match(/javascript/i)) {
            typeDefinition = typesArrayJavascript.join("\n");
        }
        if (paradigm === null || paradigm === void 0 ? void 0 : paradigm.match(/typescript/i)) {
            typeDefinition = typesArrayTypeScript.join("\n");
        }
    }
    catch (error) {
        console.log(error.message);
        typeDefinition = null;
    }
    return typeDefinition;
}
