import serverError from "./serverError";
import fs from "fs";
import path from "path";

/**
 * # Grab User Schema Data
 */
export default function grabUserSchemaData({
    userId,
}: {
    userId: string | number;
}): import("../../types").DSQL_DatabaseSchemaType[] | null {
    try {
        const userSchemaFilePath = path.resolve(
            process.cwd(),
            `${process.env.DSQL_USER_DB_SCHEMA_PATH}/user-${userId}/main.json`
        );
        const userSchemaData = JSON.parse(
            fs.readFileSync(userSchemaFilePath, "utf-8")
        );

        return userSchemaData;
    } catch (error: any) {
        serverError({
            component: "grabUserSchemaData",
            message: error.message,
        });

        global.ERROR_CALLBACK?.(
            `Error Grabbing User Schema Data`,
            error as Error
        );

        return null;
    }
}
